package weimob

import (
	"bytes"
	"encoding/json"
	"io/ioutil"
	"net/http"
)

type WeimobConfig struct {
	ApiUrl     string
	ServerName string
}

func NewWeChatClient(ServerName, ApiUrl string) *WeimobConfig {
	return &WeimobConfig{
		ServerName: ServerName, //项目名
		ApiUrl:     ApiUrl,     //无特殊情况为 "https://dopen.weimob.com/",
	}
}

//post json参数
func (w *WeimobConfig) PostJSON(url string, data []byte) string {
	req, err := http.NewRequest("POST", url, bytes.NewReader(data))
	if err != nil {
		return ""
	}
	req.Header.Set("Content-Type", "application/json")
	req.Header.Set("service_name", w.ServerName)
	client := http.Client{}
	resp, err := client.Do(req)
	if err != nil || resp.StatusCode != 200 {

		return ""
	}
	respBytes, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		return ""
	}
	return string(respBytes)
}

//Json post
func (w *WeimobConfig) DoPost(url string, params map[string]interface{}) string {
	data, errp := json.Marshal(params)
	if errp != nil {
		//	logs.Log("POST/PostJSON/ERR", "error", "参数json化错误:【%v】 ", errp)

		return ""
	}
	req, err := http.NewRequest("POST", url, bytes.NewReader(data))
	if err != nil {
		return ""
	}
	req.Header.Set("Content-Type", "application/json")
	req.Header.Set("service_name", w.ServerName)
	client := http.Client{}
	resp, err := client.Do(req)
	if err != nil || resp.StatusCode != 200 {

		return ""
	}
	respBytes, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		return ""
	}
	return string(respBytes)
}
